@@ -449,14 +449,13 @@ class MVForecaster:
                     self.grid_evaluated["optimized_metric"]
                     == self.grid_evaluated["optimized_metric"].max()
                 ].index.to_list()[0]
-                self.best_params = dict(self.grid.loc[best_params_idx])
             else:
                 best_params_idx = self.grid.loc[
                     self.grid_evaluated["optimized_metric"]
                     == self.grid_evaluated["optimized_metric"].min()
                 ].index.to_list()[0]
-                self.best_params = dict(self.grid.loc[best_params_idx])
-
+                
+            self.best_params = {k: v[best_params_idx] for k, v in self.grid.to_dict(orient='series').items()}
             self.validation_metric_value = self.grid_evaluated.loc[
                 best_params_idx, "optimized_metric"
             ]
